@@ -21,7 +21,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
     /**
      * @dataProvider provideTestDefaultValues
      */
-    public function testDefaultValues($value, $expectedValueNode) {
+    public function testDefaultValues($value, $expectedValueNode): void {
         $node = $this->createParamBuilder('test')
             ->setDefault($value)
             ->getNode()
@@ -30,7 +30,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         $this->assertEquals($expectedValueNode, $node->default);
     }
 
-    public function provideTestDefaultValues() {
+    public static function provideTestDefaultValues() {
         return [
             [
                 null,
@@ -89,7 +89,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
      * @dataProvider provideTestNullableTypes
      * @dataProvider provideTestUnionTypes
      */
-    public function testTypes($typeHint, $expectedType) {
+    public function testTypes($typeHint, $expectedType): void {
         $node = $this->createParamBuilder('test')
             ->setType($typeHint)
             ->getNode()
@@ -107,7 +107,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         $this->assertEquals($expectedType, $type);
     }
 
-    public function provideTestTypes() {
+    public static function provideTestTypes() {
         return [
             ['array', new Node\Identifier('array')],
             ['callable', new Node\Identifier('callable')],
@@ -127,7 +127,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         ];
     }
 
-    public function provideTestNullableTypes() {
+    public static function provideTestNullableTypes() {
         return [
             ['?array', new Node\NullableType(new Node\Identifier('array'))],
             ['?Some\Class', new Node\NullableType(new Node\Name('Some\Class'))],
@@ -142,7 +142,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         ];
     }
 
-    public function provideTestUnionTypes() {
+    public static function provideTestUnionTypes() {
         return [
             [
                 new Node\UnionType([
@@ -169,19 +169,19 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         ];
     }
 
-    public function testVoidTypeError() {
+    public function testVoidTypeError(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Parameter type cannot be void');
         $this->createParamBuilder('test')->setType('void');
     }
 
-    public function testInvalidTypeError() {
+    public function testInvalidTypeError(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Type must be a string, or an instance of Name, Identifier or ComplexType');
         $this->createParamBuilder('test')->setType(new \stdClass());
     }
 
-    public function testByRef() {
+    public function testByRef(): void {
         $node = $this->createParamBuilder('test')
             ->makeByRef()
             ->getNode()
@@ -193,7 +193,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testVariadic() {
+    public function testVariadic(): void {
         $node = $this->createParamBuilder('test')
             ->makeVariadic()
             ->getNode()
@@ -205,7 +205,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testMakePublic() {
+    public function testMakePublic(): void {
         $node = $this->createParamBuilder('test')
             ->makePublic()
             ->getNode()
@@ -217,7 +217,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testMakeProtected() {
+    public function testMakeProtected(): void {
         $node = $this->createParamBuilder('test')
             ->makeProtected()
             ->getNode()
@@ -229,7 +229,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testMakePrivate() {
+    public function testMakePrivate(): void {
         $node = $this->createParamBuilder('test')
             ->makePrivate()
             ->getNode()
@@ -241,7 +241,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testMakeReadonly() {
+    public function testMakeReadonly(): void {
         $node = $this->createParamBuilder('test')
             ->makeReadonly()
             ->getNode()
@@ -253,7 +253,7 @@ class ParamTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testAddAttribute() {
+    public function testAddAttribute(): void {
         $attribute = new Attribute(
             new Name('Attr'),
             [new Arg(new Int_(1), false, false, [], new Identifier('name'))]
